# Developer-Examples

## Applications (MariaDB Connector Examples)

### [Bookings](https://github.com/mariadb-corporation/dev-example-bookings)
**Bookings** is a web application that, backed by the power of MariaDB connectors and the [MariaDB X4 Platform](https://mariadb.com/resources/blog/deploying-mariadb-platform-x4/#smart), unleashes the power of [smart transactions](https://mariadb.com/resources/blog/introducing-mariadb-platform-x4-smart-transactions-and-cloud-native-storage/) on hundreds of millions of records with sub-second query performance without having to add any indexes!

### [Flights](https://github.com/mariadb-corporation/dev-example-flights)
**Flights** is a web application that, backed by the power of MariaDB connectors and [MariaDB ColumnStore database](https://mariadb.com/docs/features/mariadb-columnstore/), allows you to analyze over 180 million [flight records from the United States Department of Transportation](https://www.transtats.bts.gov/DL_SelectFields.asp?Table_ID=236&DB_Short_Name=On-Time) in real time without needing to add any indexes!

### [Orders](https://github.com/mariadb-corporation/dev-example-orders)

**Orders** is a web application that, backed by the power of MariaDB connectors, introduces you to the power, performance, and simplicity of [MariaDB](https://mariadb.com/products/).

### [Places](https://github.com/mariadb-corporation/dev-example-places)
**Places** is a web application that, backed by the power of MariaDB connectors and [MariaDB platform](https://mariadb.com/products/mariadb-platform/), allows you to record all of your favorite locations!

### [TODO](https://github.com/mariadb-corporation/dev-example-todo)
**TODO** is a web application that that introduces you to the power, performance and simplicity of [MariaDB](https://mariadb.com/products/). Through the use of simple task management you'll learn how to interact with MariaDB databases and perform simple CRUD operations!

## Other Samples

### [Getting started with Community Server 10.5 and HTAP](https://github.com/mariadb-corporation/dev-example-htap-community)

[MariaDB Community Server 10.5](https://mariadb.com/resources/blog/whats-new-in-mariadb-community-server-10-5/) has many enhancements that will provide an improved user experience with faster performance and improved manageability. This example walks through the process of downloading, installing and configuring MariaDB Community Server (HTAP) using a Docker Image.

### [Getting started with SkySQL and HTAP](https://github.com/mariadb-corporation/dev-example-skysql-htap-quickstart)

[MariaDB SkySQL](https://mariadb.com/products/skysql/docs/) is the best database-as-a-service (DBaaS) available today. It’s the first DBaaS to support OLTP, OLAP and hybrid workloads, storing data both in row format on persistent block storage and columnar format on object storage. This sample will get you up and running with a MariaDB SkySQL [Hybrid Transactional/Analytical Processing (HTAP)](https://mariadb.com/docs/solutions/htap/) database instance in less than 15 minutes.

### [Introduction to MariaDB Connector/Python](https://github.com/mariadb-corporation/dev-example-connector-python)

This repository provides a variety of samples that utilize [MariaDB Connector/Python](https://mariadb.com/docs/appdev/connector-python/).

### [Modern SQL Samples and Apache Zeppelin](https://github.com/mariadb-corporation/dev-example-modern-sql)

[MariaDB](http://www.mariadb.com) implements more of the standard SQL specification than any other open source database, adding support for [common table expressions (CTEs)](https://mariadb.com/kb/en/with/), [window functions](https://mariadb.com/kb/en/window-functions/), [temporal data tables](https://mariadb.com/kb/en/temporal-data-tables/) and many other features over the last few years. 

### [Object-Relational Mapping Samples](https://github.com/mariadb-corporation/dev-example-orms)

A collection of samples highlighting the usages of Object-Relational Mapping (ORM) tools.

| App Language | Driver  | ORM       |
|--------------|---------|-----------|
| Node.js      | Node.js | Sequelize |
| Java         | JDBC    |           |
| Java         | R2DBC   |           |
| Python       | Python  |           |


## Support and Contribution <a name="support-contribution"></a>

Please feel free to submit PR's, issues or requests to this project project directly.

If you have any other questions, comments, or looking for more information on MariaDB please check out:

* [MariaDB Developer Hub](https://mariadb.com/developers)
* [MariaDB Community Slack](https://r.mariadb.com/join-community-slack)

Or reach out to us diretly via:

* [developers@mariadb.com](mailto:developers@mariadb.com)
* [MariaDB Twitter](https://twitter.com/mariadb)
